==> cucumber-groovy-1.1.3-sources.jar: cucumber/api/groovy/BM.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class BM {

    public static void Apabila(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Apabila(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Bagi(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Bagi(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dan(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Dan(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Kemudian(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Kemudian(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Tetapi(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Tetapi(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

}

==> cucumber-groovy-1.1.4-sources.jar: cucumber/api/groovy/BM.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class BM {

    public static void Apabila(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Apabila(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Bagi(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Bagi(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dan(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Dan(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Diberi(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Diberi(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Kemudian(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Kemudian(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Maka(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Maka(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Tapi(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Tapi(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Tetapi(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Tetapi(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

}
